import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { MarkerAutomaticBehavior_$type } from "./MarkerAutomaticBehavior";
import { SeriesHighlightingMode_$type } from "./SeriesHighlightingMode";
import { SeriesSelectionMode_$type } from "./SeriesSelectionMode";
import { SeriesSelectionBehavior_$type } from "./SeriesSelectionBehavior";
import { SeriesViewerScrollbarMode_$type } from "./SeriesViewerScrollbarMode";
import { SeriesViewerHorizontalScrollbarPosition_$type } from "./SeriesViewerHorizontalScrollbarPosition";
import { SeriesViewerVerticalScrollbarPosition_$type } from "./SeriesViewerVerticalScrollbarPosition";
import { SeriesHighlightingBehavior_$type } from "./SeriesHighlightingBehavior";
import { LegendHighlightingMode_$type } from "./LegendHighlightingMode";
import { LegendItemBadgeShape_$type } from "igniteui-react-core";
import { LegendItemBadgeMode_$type } from "igniteui-react-core";
import { ChartHitTestMode_$type } from "./ChartHitTestMode";
import { WindowResponse_$type } from "./WindowResponse";
import { Visibility_$type } from "igniteui-react-core";
import { ZoomCoercionMode_$type } from "./ZoomCoercionMode";
import { InteractionState_$type } from "igniteui-react-core";
import { ModifierKeys_$type } from "igniteui-react-core";
import { SeriesHighlightedValuesDisplayMode_$type } from "igniteui-react-core";
import { IgrChartSelectedItemCollection } from "./igr-chart-selected-item-collection";
import { HorizontalAlignment_$type } from "igniteui-react-core";
import { IgrPlotAreaMouseButtonEventArgs } from "./igr-plot-area-mouse-button-event-args";
import { IgrPlotAreaMouseEventArgs } from "./igr-plot-area-mouse-event-args";
import { IgrChartCursorEventArgs } from "./igr-chart-cursor-event-args";
import { IgrDataChartMouseButtonEventArgs } from "./igr-data-chart-mouse-button-event-args";
import { IgrChartMouseEventArgs } from "./igr-chart-mouse-event-args";
import { IgrSeriesViewerManipulationEventArgs } from "./igr-series-viewer-manipulation-event-args";
import { IgrRectChangedEventArgs } from "igniteui-react-core";
import { IgrSeriesViewerSelectedSeriesItemsChangedEventArgs } from "./igr-series-viewer-selected-series-items-changed-event-args";
import { IgrRefreshCompletedEventArgs } from "./igr-refresh-completed-event-args";
import { IgrImageCapturedEventArgs } from "igniteui-react-core";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, toBrushCollection, fromBrushCollection, ensureEnum, fromPoint, toPoint, ensureBool, brushToString, stringToBrush, fromRect, toRect, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { ChartSelectedItemCollection as ChartSelectedItemCollection_internal } from "./ChartSelectedItemCollection";
import { ChartSelection } from "./ChartSelection";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * Represents a control for viewing series objects.
*/
export class IgrSeriesViewer extends React.Component {
    createImplementation() {
        return null;
    }
    get nativeElement() {
        return this._implementation.nativeElement;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.mounted = false;
        this._selectedSeriesItems = null;
        this._focusedSeriesItems = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._plotAreaMouseLeftButtonDown = null;
        this._plotAreaMouseLeftButtonDown_wrapped = null;
        this._plotAreaMouseLeftButtonUp = null;
        this._plotAreaMouseLeftButtonUp_wrapped = null;
        this._plotAreaClicked = null;
        this._plotAreaClicked_wrapped = null;
        this._plotAreaMouseEnter = null;
        this._plotAreaMouseEnter_wrapped = null;
        this._plotAreaMouseLeave = null;
        this._plotAreaMouseLeave_wrapped = null;
        this._plotAreaMouseOver = null;
        this._plotAreaMouseOver_wrapped = null;
        this._seriesCursorMouseMove = null;
        this._seriesCursorMouseMove_wrapped = null;
        this._seriesMouseLeftButtonDown = null;
        this._seriesMouseLeftButtonDown_wrapped = null;
        this._seriesMouseLeftButtonUp = null;
        this._seriesMouseLeftButtonUp_wrapped = null;
        this._seriesClick = null;
        this._seriesClick_wrapped = null;
        this._seriesMouseMove = null;
        this._seriesMouseMove_wrapped = null;
        this._seriesMouseEnter = null;
        this._seriesMouseEnter_wrapped = null;
        this._seriesMouseLeave = null;
        this._seriesMouseLeave_wrapped = null;
        this._viewerManipulationStarting = null;
        this._viewerManipulationStarting_wrapped = null;
        this._viewerManipulationEnding = null;
        this._viewerManipulationEnding_wrapped = null;
        this._windowRectChanged = null;
        this._windowRectChanged_wrapped = null;
        this._sizeChanged = null;
        this._sizeChanged_wrapped = null;
        this._actualWindowRectChanged = null;
        this._actualWindowRectChanged_wrapped = null;
        this._gridAreaRectChanged = null;
        this._gridAreaRectChanged_wrapped = null;
        this._selectedSeriesItemsChanged = null;
        this._selectedSeriesItemsChanged_wrapped = null;
        this._focusedSeriesItemsChanged = null;
        this._focusedSeriesItemsChanged_wrapped = null;
        this._refreshCompleted = null;
        this._refreshCompleted_wrapped = null;
        this._imageCaptured = null;
        this._imageCaptured_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.mounted = true;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    /**
     * Gets or sets the palette of brushes used for fill of plotted series.
     * These brushes are automatically assigned to series based on the index of series.
    */
    get brushes() {
        return fromBrushCollection(this.i.ag);
    }
    set brushes(v) {
        this.i.ag = toBrushCollection(v);
    }
    /**
     * Gets or sets the palette of brushes used for outlines of plotted series.
     * These outlines are automatically assigned to series based on the index of series.
    */
    get outlines() {
        return fromBrushCollection(this.i.aj);
    }
    set outlines(v) {
        this.i.aj = toBrushCollection(v);
    }
    /**
     * Gets or sets the palette of brushes used for fill of marker series.
     * These brushes are automatically assigned to markers based on the index of series.
    */
    get markerBrushes() {
        return fromBrushCollection(this.i.ah);
    }
    set markerBrushes(v) {
        this.i.ah = toBrushCollection(v);
    }
    /**
     * Gets or sets the palette of brushes used for outlines of plotted markers.
     * These outlines are automatically assigned to markers based on the index of series.
    */
    get markerOutlines() {
        return fromBrushCollection(this.i.ai);
    }
    set markerOutlines(v) {
        this.i.ai = toBrushCollection(v);
    }
    /**
     * Gets or sets the marker mode used for assigning a marker type to series when the marker type is automatic.
    */
    get markerAutomaticBehavior() {
        return this.i.bg;
    }
    set markerAutomaticBehavior(v) {
        this.i.bg = ensureEnum(MarkerAutomaticBehavior_$type, v);
    }
    /**
     * Gets or sets the cross hair point (in world coordinates)
     * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
     * case the relevant crosshair line is hidden.
    *
    * The `CrosshairPoint` property is used to gets/sets the cross hair point (in world coordinates).
    *
    * ```ts
    * this.chart.crosshairPoint = {x:.8,y:.2};
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	crosshairVisibility="visible"
    *     crosshairPoint={x:.8,y:.2} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get crosshairPoint() {
        return fromPoint(this.i.vv);
    }
    set crosshairPoint(v) {
        this.i.vv = toPoint(v);
    }
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    *
    * `AnimateSeriesWhenAxisRangeChanges` is a Boolean property to override the default behavior in which series do not animate if an axis range changes.
    *
    * ```ts
    * this.chart.animateSeriesWhenAxisRangeChanges = true;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	animateSeriesWhenAxisRangeChanges={true}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrColumnSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get animateSeriesWhenAxisRangeChanges() {
        return this.i.ek;
    }
    set animateSeriesWhenAxisRangeChanges(v) {
        this.i.ek = ensureBool(v);
    }
    /**
     * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
    */
    get seriesValueLayerUseLegend() {
        return this.i.f2;
    }
    set seriesValueLayerUseLegend(v) {
        this.i.f2 = ensureBool(v);
    }
    /**
     * Gets or sets whether to sync the vertical aspect of the window with the contained series content. This is only supported for a subset of the available series.
    */
    get isWindowSyncedToVisibleRange() {
        return this.i.fj;
    }
    set isWindowSyncedToVisibleRange(v) {
        this.i.fj = ensureBool(v);
    }
    /**
     * Gets or sets whether calling SimulateHover should shift the crosshair point.
    */
    get shouldSimulateHoverMoveCrosshairPoint() {
        return this.i.f7;
    }
    set shouldSimulateHoverMoveCrosshairPoint(v) {
        this.i.f7 = ensureBool(v);
    }
    /**
     * Gets or sets the highlighting mode to use for the series in the component, when supported. This takes precedence over the series level IsHighlightingEnabled.
    */
    get highlightingMode() {
        return this.i.by;
    }
    set highlightingMode(v) {
        this.i.by = ensureEnum(SeriesHighlightingMode_$type, v);
    }
    /**
     * Gets or sets the selection mode to use for the series in the component, when supported.
    */
    get selectionMode() {
        return this.i.cb;
    }
    set selectionMode(v) {
        this.i.cb = ensureEnum(SeriesSelectionMode_$type, v);
    }
    /**
     * Gets or sets the selection behavior to use for the series in the component, when supported.
    */
    get selectionBehavior() {
        return this.i.b6;
    }
    set selectionBehavior(v) {
        this.i.b6 = ensureEnum(SeriesSelectionBehavior_$type, v);
    }
    /**
     * Gets or sets the focus mode to use for the series in the component, when supported.
    */
    get focusMode() {
        return this.i.b9;
    }
    set focusMode(v) {
        this.i.b9 = ensureEnum(SeriesSelectionMode_$type, v);
    }
    /**
     * Gets or sets the horizontal scrollbar mode to use for the series viewer.
    */
    get horizontalViewScrollbarMode() {
        return this.i.ch;
    }
    set horizontalViewScrollbarMode(v) {
        this.i.ch = ensureEnum(SeriesViewerScrollbarMode_$type, v);
    }
    /**
     * Gets or sets the vertical scrollbar mode to use for the series viewer.
    */
    get verticalViewScrollbarMode() {
        return this.i.ci;
    }
    set verticalViewScrollbarMode(v) {
        this.i.ci = ensureEnum(SeriesViewerScrollbarMode_$type, v);
    }
    /**
     * Gets or sets the position to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarPosition() {
        return this.i.ce;
    }
    set horizontalViewScrollbarPosition(v) {
        this.i.ce = ensureEnum(SeriesViewerHorizontalScrollbarPosition_$type, v);
    }
    /**
     * Gets or sets the position to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarPosition() {
        return this.i.cl;
    }
    set verticalViewScrollbarPosition(v) {
        this.i.cl = ensureEnum(SeriesViewerVerticalScrollbarPosition_$type, v);
    }
    /**
     * Gets or sets the fill to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarFill() {
        return brushToString(this.i.vi);
    }
    set horizontalViewScrollbarFill(v) {
        this.i.vi = stringToBrush(v);
    }
    /**
     * Gets or sets the outline to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarOutline() {
        return brushToString(this.i.vj);
    }
    set horizontalViewScrollbarOutline(v) {
        this.i.vj = stringToBrush(v);
    }
    /**
     * Gets or sets the stroke thickness to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarStrokeThickness() {
        return this.i.hy;
    }
    set horizontalViewScrollbarStrokeThickness(v) {
        this.i.hy = +v;
    }
    /**
     * Gets or sets the max opacity to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarMaxOpacity() {
        return this.i.hx;
    }
    set horizontalViewScrollbarMaxOpacity(v) {
        this.i.hx = +v;
    }
    /**
     * Gets or sets the corner radius to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarCornerRadius() {
        return this.i.hu;
    }
    set horizontalViewScrollbarCornerRadius(v) {
        this.i.hu = +v;
    }
    /**
     * Gets or sets the height to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarHeight() {
        return this.i.hv;
    }
    set horizontalViewScrollbarHeight(v) {
        this.i.hv = +v;
    }
    /**
     * Gets or sets the inset distance to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarInset() {
        return this.i.hw;
    }
    set horizontalViewScrollbarInset(v) {
        this.i.hw = +v;
    }
    /**
     * Gets or sets the track start inset to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarTrackStartInset() {
        return this.i.h0;
    }
    set horizontalViewScrollbarTrackStartInset(v) {
        this.i.h0 = +v;
    }
    /**
     * Gets or sets the track end inset to use for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarTrackEndInset() {
        return this.i.hz;
    }
    set horizontalViewScrollbarTrackEndInset(v) {
        this.i.hz = +v;
    }
    /**
     * Gets or sets whether to use automatic track insets for the horizontal scrollbar in the component, when enabled.
    */
    get horizontalViewScrollbarShouldAddAutoTrackInsets() {
        return this.i.ey;
    }
    set horizontalViewScrollbarShouldAddAutoTrackInsets(v) {
        this.i.ey = ensureBool(v);
    }
    /**
     * Gets or sets the fill to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarFill() {
        return brushToString(this.i.vs);
    }
    set verticalViewScrollbarFill(v) {
        this.i.vs = stringToBrush(v);
    }
    /**
     * Gets or sets the outline to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarOutline() {
        return brushToString(this.i.vt);
    }
    set verticalViewScrollbarOutline(v) {
        this.i.vt = stringToBrush(v);
    }
    /**
     * Gets or sets the stroke thickness to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarStrokeThickness() {
        return this.i.il;
    }
    set verticalViewScrollbarStrokeThickness(v) {
        this.i.il = +v;
    }
    /**
     * Gets or sets the max opacity to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarMaxOpacity() {
        return this.i.ik;
    }
    set verticalViewScrollbarMaxOpacity(v) {
        this.i.ik = +v;
    }
    /**
     * Gets or sets the corner radius to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarCornerRadius() {
        return this.i.ii;
    }
    set verticalViewScrollbarCornerRadius(v) {
        this.i.ii = +v;
    }
    /**
     * Gets or sets the width to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarWidth() {
        return this.i.ip;
    }
    set verticalViewScrollbarWidth(v) {
        this.i.ip = +v;
    }
    /**
     * Gets or sets the inset distance to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarInset() {
        return this.i.ij;
    }
    set verticalViewScrollbarInset(v) {
        this.i.ij = +v;
    }
    /**
     * Gets or sets the track start inset to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarTrackStartInset() {
        return this.i.io;
    }
    set verticalViewScrollbarTrackStartInset(v) {
        this.i.io = +v;
    }
    /**
     * Gets or sets the track end inset to use for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarTrackEndInset() {
        return this.i.im;
    }
    set verticalViewScrollbarTrackEndInset(v) {
        this.i.im = +v;
    }
    /**
     * Gets or sets whether to use automatic track insets for the vertical scrollbar in the component, when enabled.
    */
    get verticalViewScrollbarShouldAddAutoTrackInsets() {
        return this.i.gj;
    }
    set verticalViewScrollbarShouldAddAutoTrackInsets(v) {
        this.i.gj = ensureBool(v);
    }
    /**
     * Gets or sets the highlighting Behavior to use for the series in the component, when supported. This takes precedence over the series level IsHighlightingEnabled.
    */
    get highlightingBehavior() {
        return this.i.bw;
    }
    set highlightingBehavior(v) {
        this.i.bw = ensureEnum(SeriesHighlightingBehavior_$type, v);
    }
    /**
     * Gets or sets the highlighting mode to use for the legend linked to the component, when supported.
    */
    get legendHighlightingMode() {
        return this.i.bd;
    }
    set legendHighlightingMode(v) {
        this.i.bd = ensureEnum(LegendHighlightingMode_$type, v);
    }
    /**
     * Gets or sets type of legend badges representing all series displayed in a legend linked to this component
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeShape() {
        return this.i.bf;
    }
    set legendItemBadgeShape(v) {
        this.i.bf = ensureEnum(LegendItemBadgeShape_$type, v);
    }
    /**
     * Gets or sets the mode of legend badges representing all series in this chart.
     * This property will be ignored when the LegendItemTemplate or LegendItemBadgeTemplate property is set on a series
    */
    get legendItemBadgeMode() {
        return this.i.be;
    }
    set legendItemBadgeMode(v) {
        this.i.be = ensureEnum(LegendItemBadgeMode_$type, v);
    }
    /**
     * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
    */
    get viewportRect() {
        return fromRect(this.i.wk);
    }
    /**
     * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
    *
    *  ``ts
    * let viewport: IgxRect = this.chart.effectiveViewport;
    *
    * ```
    *
    * ```
    */
    get effectiveViewport() {
        return fromRect(this.i.v8);
    }
    set effectiveViewport(v) {
        this.i.v8 = toRect(v);
    }
    /**
     * Represents the subset area within the viewport into which content should be mapped.
     * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
    */
    get contentViewport() {
        return fromRect(this.i.v7);
    }
    /**
     * A rectangle representing the portion of the SeriesViewer currently in view.
     * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
    *
    * You can set the `WindowRect` to zoom in on an area of interest in the chart.
    *
    * ```ts
    * this.chart.windowRect = {left:0, top:1, width: .5, height: .5};
    * ```
    */
    get windowRect() {
        return fromRect(this.i.wl);
    }
    set windowRect(v) {
        this.i.wl = toRect(v);
    }
    /**
     * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
    */
    get useTiledZooming() {
        return this.i.gi;
    }
    set useTiledZooming(v) {
        this.i.gi = ensureBool(v);
    }
    /**
     * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
    */
    get preferHigherResolutionTiles() {
        return this.i.fz;
    }
    set preferHigherResolutionTiles(v) {
        this.i.fz = ensureBool(v);
    }
    /**
     * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
    */
    get zoomTileCacheSize() {
        return this.i.i8;
    }
    set zoomTileCacheSize(v) {
        this.i.i8 = +v;
    }
    /**
     * Gets or sets the duration the highlighting/de-highlighting effects.
    *
    * The `HighlightingTransitionDuration` property is used to set the time for highlighting transition in milliseconds .
    *
    * ```ts
    * chart.HighlightingTransitionDuration=500;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	HighlightingTransitionDuration={500} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get highlightingTransitionDuration() {
        return this.i.i5;
    }
    set highlightingTransitionDuration(v) {
        this.i.i5 = +v;
    }
    /**
     * Gets or sets the duration the selection/de-Selection effects.
    */
    get selectionTransitionDuration() {
        return this.i.i7;
    }
    set selectionTransitionDuration(v) {
        this.i.i7 = +v;
    }
    /**
     * Gets or sets the duration the Focus/de-Focus effects.
    */
    get focusTransitionDuration() {
        return this.i.i3;
    }
    set focusTransitionDuration(v) {
        this.i.i3 = +v;
    }
    /**
     * Gets or sets the duration of the scrollbar effects.
    */
    get scrollbarsAnimationDuration() {
        return this.i.i6;
    }
    set scrollbarsAnimationDuration(v) {
        this.i.i6 = +v;
    }
    /**
     * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
    */
    get isPagePanningAllowed() {
        return this.i.fe;
    }
    set isPagePanningAllowed(v) {
        this.i.fe = ensureBool(v);
    }
    /**
     * Determines the method of hit testing used when mousing over elements in the chart.
    *
    * ```ts
    * this.chart.contentHitTestMode = ChartHitTestMode.Computational;
    * ```
    */
    get contentHitTestMode() {
        return this.i.av;
    }
    set contentHitTestMode(v) {
        this.i.av = ensureEnum(ChartHitTestMode_$type, v);
    }
    /**
     * Resolved method of hit testing used when the pointer is over elements in the chart.
    *
    * ```ts
    * let actualContentHitTestMode: ChartHitTestMode  =this.chart.actualContentHitTestMode;
    * ```
    */
    get actualContentHitTestMode() {
        return this.i.au;
    }
    set actualContentHitTestMode(v) {
        this.i.au = ensureEnum(ChartHitTestMode_$type, v);
    }
    /**
     * Gets or sets whether all surface interactions with the plot area should be disabled.
    *
    * The `IsSurfaceInteractionDisabled` property is used to enable/disable interactions with the plot surface.
    *
    * ```ts
    * chart.isSurfaceInteractionDisabled=true;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	 isSurfaceInteractionDisabled={true} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get isSurfaceInteractionDisabled() {
        return this.i.ff;
    }
    set isSurfaceInteractionDisabled(v) {
        this.i.ff = ensureBool(v);
    }
    /**
     * Indicates if this SeriesViewer is a map.
    */
    get isMap() {
        return this.i.fd;
    }
    /**
     * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
    *
    * The `WindowResponse` property is used to set the response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.
    * The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
    *
    * ```ts
    * this.chart.windowResponse="deferred";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	windowResponse="deferred">
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get windowResponse() {
        return this.i.cp;
    }
    set windowResponse(v) {
        this.i.cp = ensureEnum(WindowResponse_$type, v);
    }
    /**
     * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property accepts values between 0.0 (max zooming) and 1.0 (no zooming)
    *
    * The `WindowRectMinWidth` property is used to set or get the minimum width that the window rect is allowed to reach before being clamped.
    *
    * ```ts
    * this.chart.WindowRectMinWidth=".2";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	WindowRectMinWidth=".2">
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get windowRectMinWidth() {
        return this.i.it;
    }
    set windowRectMinWidth(v) {
        this.i.it = +v;
    }
    /**
     * Sets or gets the minimum height that the window rect is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property accepts values between 0.0 (max zooming) and 1.0 (no zooming)
    */
    get windowRectMinHeight() {
        return this.i.is;
    }
    set windowRectMinHeight(v) {
        this.i.is = +v;
    }
    /**
     * Gets the actual minimum width that the window rect is allowed to reach before being clamped.
    */
    get actualWindowRectMinWidth() {
        return this.i.hm;
    }
    set actualWindowRectMinWidth(v) {
        this.i.hm = +v;
    }
    /**
     * Gets the actual minimum height that the window rect is allowed to reach before being clamped.
    */
    get actualWindowRectMinHeight() {
        return this.i.hl;
    }
    set actualWindowRectMinHeight(v) {
        this.i.hl = +v;
    }
    /**
     * Sets or gets minimum pixel width that the window is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property is overridden by the WindowRectMinWidth property
    */
    get windowSizeMinWidth() {
        return this.i.iv;
    }
    set windowSizeMinWidth(v) {
        this.i.iv = +v;
    }
    /**
     * Sets or gets minimum pixel height that the window is allowed to reach before being clamped.
     * Decrease this value if you want to allow for further zooming into the viewer.
     * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
     * This property is overridden by the WindowRectMinHeight property
    */
    get windowSizeMinHeight() {
        return this.i.iu;
    }
    set windowSizeMinHeight(v) {
        this.i.iu = +v;
    }
    /**
     * Gets or sets the current SeriesViewer's crosshair visibility override.
    *
    * The `CrosshairVisibility` property is used to gets or sets the current Chart's crosshair visibility override. Note: setting this property does not affect the mobile browser version of the chart.
    *
    * ```ts
    * this.chart.crosshairVisibility = Visibility.Visible;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	crosshairVisibility="visible"
    *     crosshairPoint={x:.8,y:.2} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get crosshairVisibility() {
        return this.i.wp;
    }
    set crosshairVisibility(v) {
        this.i.wp = ensureEnum(Visibility_$type, v);
    }
    /**
     * Gets or sets the current SeriesViewer's crosshair horizontal brush override.
    */
    get horizontalCrosshairBrush() {
        return brushToString(this.i.vh);
    }
    set horizontalCrosshairBrush(v) {
        this.i.vh = stringToBrush(v);
    }
    /**
     * Gets or sets the current SeriesViewer's crosshair vertical brush override.
    */
    get verticalCrosshairBrush() {
        return brushToString(this.i.vr);
    }
    set verticalCrosshairBrush(v) {
        this.i.vr = stringToBrush(v);
    }
    /**
     * Gets or sets zoom is constrained to within the axes. Setting this to false is a preview feature at the present time.
    */
    get zoomCoercionMode() {
        return this.i.ct;
    }
    set zoomCoercionMode(v) {
        this.i.ct = ensureEnum(ZoomCoercionMode_$type, v);
    }
    /**
     * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
    *
    * `PlotAreaBackground` property set the background brush to the current Chart object's plot area.
    *
    * ```ts
    * this.chart.plotAreaBackground="#F0F8FF";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    * 	dataSource={this.state.dataSource}
    * 	plotAreaBackground="#F0F8FF" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get plotAreaBackground() {
        return brushToString(this.i.vk);
    }
    set plotAreaBackground(v) {
        this.i.vk = stringToBrush(v);
    }
    /**
     * Gets or sets whether to match the z order of the series to their positional order in the series collection, regardless of mutation.
    */
    get shouldMatchZOrderToSeriesOrder() {
        return this.i.f5;
    }
    set shouldMatchZOrderToSeriesOrder(v) {
        this.i.f5 = ensureBool(v);
    }
    /**
     * Gets or sets the DefaultInteraction property.
     * The default interaction state defines the SeriesViewer's response to mouse events.
    *
    * The default interaction state defines the chart's response to mouse events.
    *
    * ```ts
    * this.chart.defaultInteraction = InteractionState.DragPan;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	defaultInteraction="dragPan" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get defaultInteraction() {
        return this.i.cw;
    }
    set defaultInteraction(v) {
        this.i.cw = ensureEnum(InteractionState_$type, v);
    }
    /**
     * Gets or sets the InteractionOverride property.
     * The interaction override overrides the default interaction and modifiers keys and defines the SeriesViewer's response to mouse events.
    */
    get interactionOverride() {
        return this.i.cx;
    }
    set interactionOverride(v) {
        this.i.cx = ensureEnum(InteractionState_$type, v);
    }
    /**
     * Gets or sets the RightButtonDefaultInteraction property.
     * The default interaction state defines the SeriesViewer's response to right button mouse events.
    */
    get rightButtonDefaultInteraction() {
        return this.i.cz;
    }
    set rightButtonDefaultInteraction(v) {
        this.i.cz = ensureEnum(InteractionState_$type, v);
    }
    /**
     * Gets or sets the current SeriesViewer's DragModifier property.
    *
    * `DragModifier` is useful to enable zooming when zooming is not the default interaction.
    *
    * ```ts
    * this.chart.dragModifier = ModifierKeys.Alt;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	isHorizontalZoomEnabled=true
    *     defaultInteraction="dragPan"
    *     dragModifier="alt" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get dragModifier() {
        return this.i.u1;
    }
    set dragModifier(v) {
        this.i.u1 = ensureEnum(ModifierKeys_$type, v);
    }
    /**
     * Gets or sets the current SeriesViewer's PanModifier property.
    *
    * `PanModifier` is useful to enable panning when panning is not the default interaction.
    *
    * ```ts
    * this.chart.panModifier = ModifierKeys.Alt;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    * 	dataSource={this.state.dataSource}
    * 	isHorizontalZoomEnabled=true
    * 	defaultInteraction="dragZoom"
    * 	panModifier="alt" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get panModifier() {
        return this.i.u2;
    }
    set panModifier(v) {
        this.i.u2 = ensureEnum(ModifierKeys_$type, v);
    }
    /**
     * Gets or sets the current SeriesViewer's SelectionModifier property.
    */
    get selectionModifier() {
        return this.i.u3;
    }
    set selectionModifier(v) {
        this.i.u3 = ensureEnum(ModifierKeys_$type, v);
    }
    /**
     * Gets or sets the preview rectangle.
     * The preview rectangle may be set to Rect.Empty, in which case the visible preview
     * strokePath is hidden.
    *
    * `PreviewRect` can be used to highlight an area of importance.
    *
    * ```ts
    * this.chart.previewRect = {left:0,top:0,height:.5,width:.5};
    * ```
    */
    get previewRect() {
        return fromRect(this.i.we);
    }
    set previewRect(v) {
        this.i.we = toRect(v);
    }
    /**
     * Gets or sets whether and how to display highlighted values for the series by default. Note, this is distinct from the highlighting feature that indicates what is closest or under the mouse.
    */
    get highlightedValuesDisplayMode() {
        return this.i.bt;
    }
    set highlightedValuesDisplayMode(v) {
        this.i.bt = ensureEnum(SeriesHighlightedValuesDisplayMode_$type, v);
    }
    /**
     * Gets the currently selected data items.  Adding or removing data items from this collection will
     * select or deselect the visuals associated with those items.
    */
    get selectedSeriesItems() {
        if (this._selectedSeriesItems === null) {
            let coll = new IgrChartSelectedItemCollection();
            let innerColl = this.i.selectedSeriesItems;
            if (!innerColl) {
                innerColl = new ChartSelectedItemCollection_internal();
            }
            this._selectedSeriesItems = coll._fromInner(innerColl);
            this.i.selectedSeriesItems = innerColl;
        }
        return this._selectedSeriesItems;
    }
    set selectedSeriesItems(v) {
        if (this._selectedSeriesItems !== null) {
            this._selectedSeriesItems._setSyncTarget(null);
            this._selectedSeriesItems = null;
        }
        let coll = new IgrChartSelectedItemCollection();
        this._selectedSeriesItems = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(ChartSelection.$type);
        let innerColl = this.i.selectedSeriesItems;
        if (!innerColl) {
            innerColl = new ChartSelectedItemCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._selectedSeriesItems._setSyncTarget(syncColl);
        this.i.selectedSeriesItems = innerColl;
    }
    /**
     * Gets the currently focused data items.  Adding or removing data items from this collection will
     * focus or blur the visuals associated with those items.
    */
    get focusedSeriesItems() {
        if (this._focusedSeriesItems === null) {
            let coll = new IgrChartSelectedItemCollection();
            let innerColl = this.i.focusedSeriesItems;
            if (!innerColl) {
                innerColl = new ChartSelectedItemCollection_internal();
            }
            this._focusedSeriesItems = coll._fromInner(innerColl);
            this.i.focusedSeriesItems = innerColl;
        }
        return this._focusedSeriesItems;
    }
    set focusedSeriesItems(v) {
        if (this._focusedSeriesItems !== null) {
            this._focusedSeriesItems._setSyncTarget(null);
            this._focusedSeriesItems = null;
        }
        let coll = new IgrChartSelectedItemCollection();
        this._focusedSeriesItems = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(ChartSelection.$type);
        let innerColl = this.i.focusedSeriesItems;
        if (!innerColl) {
            innerColl = new ChartSelectedItemCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._focusedSeriesItems._setSyncTarget(syncColl);
        this.i.focusedSeriesItems = innerColl;
    }
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the X position of the WindowRect property.
    *
    * ```ts
    * this.chart.windowPositionHorizontal = .2;
    * ```
    */
    get windowPositionHorizontal() {
        return this.i.iq;
    }
    set windowPositionHorizontal(v) {
        this.i.iq = +v;
    }
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Y position of the WindowRect property.
    *
    * ```ts
    * this.chart.windowPositionVertical = .2;
    * ```
    */
    get windowPositionVertical() {
        return this.i.ir;
    }
    set windowPositionVertical(v) {
        this.i.ir = +v;
    }
    /**
     * Gets or sets the selection brush to use for the series.
    */
    get selectionBrush() {
        return brushToString(this.i.vo);
    }
    set selectionBrush(v) {
        this.i.vo = stringToBrush(v);
    }
    /**
     * Gets or sets the Focus brush to use for the series.
    */
    get focusBrush() {
        return brushToString(this.i.u7);
    }
    set focusBrush(v) {
        this.i.u7 = stringToBrush(v);
    }
    /**
     * Text to display above the plot area.
    *
    * The `Title` property is used to set the title to display for the component.
    *
    * ```ts
    * this.chart.title="Items Sold";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	title="Items Sold" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get chartTitle() {
        return this.i.l3;
    }
    set chartTitle(v) {
        this.i.l3 = v;
    }
    /**
     * Gets or sets the TitleHorizontalAlignment property.
    *
    * The `subtitleHorizontalAlignment` property is used to set horizontal alignment for the subtitle.
    *
    * ```ts
    * this.chart.titleHorizontalAlignment="left";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	titleHorizontalAlignment="left"
    *     subtitleHorizontalAlignment="left" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleHorizontalAlignment() {
        return this.i.u0;
    }
    set titleHorizontalAlignment(v) {
        this.i.u0 = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
     * Gets or sets the SubtitleHorizontalAlignment property.
    *
    * The `subtitleBottomMargin` property is used to set the horizontal alignment for the subtitle.
    *
    * ```ts
    * this.chart.subtitleHorizontalAlignment="left";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	subtitleHorizontalAlignment="left"	>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleHorizontalAlignment() {
        return this.i.uz;
    }
    set subtitleHorizontalAlignment(v) {
        this.i.uz = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
     * Font settings for the title.
    */
    get titleTextStyle() {
        return this.i.ma;
    }
    set titleTextStyle(v) {
        this.i.ma = v;
    }
    /**
     * Font settings for the subtitle.
    */
    get subtitleTextStyle() {
        return this.i.ly;
    }
    set subtitleTextStyle(v) {
        this.i.ly = v;
    }
    /**
     * Gets or sets the Color used for the Title Text.
    *
    * The `titleTextColor` property is used to set the title brush.
    *
    * ```ts
    * this.chart.titleTextColor="blue" ;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	titleTextColor="blue" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleTextColor() {
        return brushToString(this.i.vq);
    }
    set titleTextColor(v) {
        this.i.vq = stringToBrush(v);
    }
    /**
     * Gets or sets the Color used for the Subtitle Text.
    *
    * The `subtitleTextColor` property is used to set the color for the subtitle.
    *
    * ```ts
    * this.chart.subtitleTextColor="blue";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	title="Date of Sale: 1/1/2018"
    *     subtitleTextColor="blue">
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleTextColor() {
        return brushToString(this.i.vp);
    }
    set subtitleTextColor(v) {
        this.i.vp = stringToBrush(v);
    }
    /**
     * Margin applied above the title.
    *
    * The `titleTopMargin` property is used to set the top margin for the title.
    *
    * ```ts
    * this.chart.titleTopMargin=10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	titleLeftMarging= {10}
    *     titleTopMargin= {10 }
    *     titleRightMargin= {10}
    *     titleBottomMargin= {20}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleTopMargin() {
        return this.i.ig;
    }
    set titleTopMargin(v) {
        this.i.ig = +v;
    }
    /**
     * Margin applied to the left of the title.
    *
    * The `titleLeftMarging` property is used to set the left margin for the title.
    *
    * ```ts
    * this.chart.titleLeftMarging=10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	title="Items Sold"
    *     titleLeftMarging={10}
    *     titleTopMargin={10}
    *     titleRightMargin={10}
    *     titleBottomMargin= {20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleLeftMargin() {
        return this.i.id;
    }
    set titleLeftMargin(v) {
        this.i.id = +v;
    }
    /**
     * Margin applied to the right of the title.
    *
    * The `titleRightMargin` property is used to set the right margin for the title.
    *
    * ```ts
    * this.chart.titleRightMargin=10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	titleLeftMarging= {10}
    *     titleTopMargin= {10 }
    *     titleRightMargin= {10}
    *     titleBottomMargin= {20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleRightMargin() {
        return this.i.ie;
    }
    set titleRightMargin(v) {
        this.i.ie = +v;
    }
    /**
     * Margin applied below the title.
    *
    * The `titleBottomMargin` property is used to set the bottom margin for the title.
    *
    * ```ts
    * this.chart.titleBottomMargin=20;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	title="Items Sold"
    * 	titleLeftMarging= {10}
    *     titleTopMargin= {10 }
    *     titleRightMargin= {10}
    *     titleBottomMargin= {20}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get titleBottomMargin() {
        return this.i.ic;
    }
    set titleBottomMargin(v) {
        this.i.ic = +v;
    }
    /**
     * Margin applied above the subtitle.
    *
    * The `subtitleTopMargin` property is used to set the top margin for the subtitle.
    *
    * ```ts
    * this.chart.subtitleTopMargin =10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	subtitleLeftMarging= {10}
    *     subtitleTopMargin={10}
    *     subtitleRightMargin={10}
    *     subtitleBottomMargin={20}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleTopMargin() {
        return this.i.ib;
    }
    set subtitleTopMargin(v) {
        this.i.ib = +v;
    }
    /**
     * Margin applied to the left of the subtitle.
    *
    * The `subtitleLeftMarging` property is used to set the left margin for the subtitle.
    *
    * ```ts
    * this.chart.subtitleLeftMarging=10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	subtitleLeftMarging= {10}
    *     subtitleTopMargin={10}
    *     subtitleRightMargin={10}
    *     subtitleBottomMargin={20}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleLeftMargin() {
        return this.i.h9;
    }
    set subtitleLeftMargin(v) {
        this.i.h9 = +v;
    }
    /**
     * Margin applied to the right of the subtitle.
    *
    * The `subTitleRightMargin` property is used to set the right margin for the subtitle.
    *
    * ```ts
    * this.chart.subtitleLeftMarging=10;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	subtitleLeftMarging= {10}
    *     subtitleTopMargin= {10}
    *     subtitleRightMargin={10}
    *     subtitleBottomMargin={20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleRightMargin() {
        return this.i.ia;
    }
    set subtitleRightMargin(v) {
        this.i.ia = +v;
    }
    /**
     * Margin applied below the subtitle.
    *
    * The `subtitleBottomMargin` property is used to set the bottom margin for the subtitle.
    *
    * ```ts
    * this.chart.subtitleBottomMargin = 20;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	 subtitleBottomMargin={20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitleBottomMargin() {
        return this.i.h8;
    }
    set subtitleBottomMargin(v) {
        this.i.h8 = +v;
    }
    /**
     * Gets or sets the Subtitle property.
     * The Title property defines the Subtitle of the chart
    *
    * The `Subtitle` property is used to display subtitle for the component.
    *
    * ```ts
    * this.chart.subtitle="Date of Sale: 1/1/2018";
    * ```
    *
    * ```ts
    *  <IgrDataChart
    * 	dataSource={this.state.dataSource}
    * 	subtitle="Date of Sale: 1/1/2018" >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get subtitle() {
        return this.i.lr;
    }
    set subtitle(v) {
        this.i.lr = v;
    }
    /**
     * Sets or gets the top margin to use around the chart content.
    *
    * The `topMargin` property is used to set the top margin.
    *
    * ```ts
    * this.chart.topMargin=30;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	leftMargin= {20}
    *     rightMargin={20}
    *     topMargin={30}
    *     bottomMargin= {20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get topMargin() {
        return this.i.ih;
    }
    set topMargin(v) {
        this.i.ih = +v;
    }
    /**
     * Sets or gets the left margin to use around the chart content.
    *
    * The `LeftMargin` property is used to set the left margin.
    *
    * ```ts
    *  this.chart.leftMargin = 20;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	 leftMargin={20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    * />
    *  </IgrDataChart>
    * ```
    */
    get leftMargin() {
        return this.i.h2;
    }
    set leftMargin(v) {
        this.i.h2 = +v;
    }
    /**
     * Sets or gets the right margin to use around the chart content.
    *
    * The `RightMargin` property is used to set the left margin around the chart content in the canvas.
    *
    * ```ts
    * this.chart.rightMargin=20;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	leftMargin= {20}
    * 	rightMargin={20}
    * 	topMargin={30}
    * 	bottomMargin={20} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get rightMargin() {
        return this.i.h7;
    }
    set rightMargin(v) {
        this.i.h7 = +v;
    }
    /**
     * Sets or gets the bottom margin to use around the chart content.
    *
    * The `bottomMargin` property is used to gets/set the bottom margin around the chart content in the canvas.
    *
    * ```ts
    * this.chart.bottomMargin = 50;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	 bottomMargin={50} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrColumnSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get bottomMargin() {
        return this.i.hp;
    }
    set bottomMargin(v) {
        this.i.hp = +v;
    }
    /**
     * Sets or gets the automatic width to add when automatically adding margins to the chart.
    *
    * The `autoMarginWidth` propertry is used find the automatic width to add when automatically adding margins to the chart.
    *
    * ```ts
    * this.chart.autoMarginWidth = 50;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	autoMarginWidth={50} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrColumnSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get autoMarginWidth() {
        return this.i.ho;
    }
    set autoMarginWidth(v) {
        this.i.ho = +v;
    }
    /**
     * Sets or gets the automatic height to add when automatically adding margins to the chart.
    *
    * ```ts
    *  this.chart.autoMarginHeight = 50;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    * 	autoMarginHeight={50}
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrAreaSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value"
    *     brush="Gray"
    *     outline="Black" />
    *  </IgrDataChart>
    * ```
    */
    get autoMarginHeight() {
        return this.i.hn;
    }
    set autoMarginHeight(v) {
        this.i.hn = +v;
    }
    /**
     * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
    */
    get isAntiAliasingEnabledDuringInteraction() {
        return this.i.e3;
    }
    set isAntiAliasingEnabledDuringInteraction(v) {
        this.i.e3 = ensureBool(v);
    }
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    get pixelScalingRatio() {
        return this.i.h3;
    }
    set pixelScalingRatio(v) {
        this.i.h3 = +v;
    }
    /**
     * Method of pixel scaling to use during end user interaction with the chart.
    */
    get interactionPixelScalingRatio() {
        return this.i.h1;
    }
    set interactionPixelScalingRatio(v) {
        this.i.h1 = +v;
    }
    /**
     * Gets the resolved pixel scaling ratio.
    *
    * A higher scaling ratio will produce crisper visuals at the expense of memory. Lower values will cause the control to appear blurry
    *
    * ```ts
    * let actualPixelScalingRatio: number = this.chart.actualPixelScalingRatio;
    * ```
    */
    get actualPixelScalingRatio() {
        return this.i.hi;
    }
    set actualPixelScalingRatio(v) {
        this.i.hi = +v;
    }
    /**
     * Resolved method of pixel scaling to use during end user interaction with the chart.
    *
    * ```ts
    * let actualInteractionPixelScalingRatio: number = this.chart.actualInteractionPixelScalingRatio;
    * ```
    */
    get actualInteractionPixelScalingRatio() {
        return this.i.hh;
    }
    set actualInteractionPixelScalingRatio(v) {
        this.i.hh = +v;
    }
    /**
     * Gets or sets a whether the chart should pan its content when zooming in passed max zoom level.
    */
    get shouldPanOnMaximumZoom() {
        return this.i.f6;
    }
    set shouldPanOnMaximumZoom(v) {
        this.i.f6 = ensureBool(v);
    }
    /**
     * Gets the actual value of the window rectangle, which represents the current zoom level.
    */
    get actualWindowRect() {
        return fromRect(this.i.v4);
    }
    set actualWindowRect(v) {
        this.i.v4 = toRect(v);
    }
    /**
     * A number between 0 and 1 determining the position of the horizontal scroll.
     * This property is effectively a shortcut to the Left of the ActualWindowRect property.
    *
    * ```ts
    * let actualWindowPositionHorizontal: number = this.chart.actualWindowPositionHorizontal;
    * ```
    */
    get actualWindowPositionHorizontal() {
        return this.i.hj;
    }
    set actualWindowPositionHorizontal(v) {
        this.i.hj = +v;
    }
    /**
     * A number between 0 and 1 determining the position of the vertical scroll.
     * This property is effectively a shortcut to the Top of the ActualWindowRect property.
    *
    * ```ts
    * let actualWindowPositionVertical: number = this.chart.actualWindowPositionVertical;
    * ``
    * ```
    */
    get actualWindowPositionVertical() {
        return this.i.hk;
    }
    set actualWindowPositionVertical(v) {
        this.i.hk = +v;
    }
    get isDetached() {
        return this.i.isDetached;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.series != null && this.series.findByName && this.series.findByName(name)) {
            return this.series.findByName(name);
        }
        if (this.legend && this.legend.name && this.legend.name == name) {
            return this.legend;
        }
        if (this.selectedSeriesItems != null && this.selectedSeriesItems.findByName && this.selectedSeriesItems.findByName(name)) {
            return this.selectedSeriesItems.findByName(name);
        }
        if (this.focusedSeriesItems != null && this.focusedSeriesItems.findByName && this.focusedSeriesItems.findByName(name)) {
            return this.focusedSeriesItems.findByName(name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("SeriesViewer");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    getDesiredToolbarActions() {
        let iv = this.i.getDesiredToolbarActions();
        return (iv);
    }
    addCommandAvailabilityListener(listener) {
        this.i.addCommandAvailabilityListener(listener);
    }
    removeCommandAvailabilityListener(listener) {
        this.i.removeCommandAvailabilityListener(listener);
    }
    addCommandStateChangedListener(listener) {
        this.i.addCommandStateChangedListener(listener);
    }
    removeCommandStateChangedListener(listener) {
        this.i.removeCommandStateChangedListener(listener);
    }
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    hideToolTip() {
        this.i.nx();
    }
    simulateHover(point) {
        this.i.rg(toPoint(point));
    }
    queueForAnimationIdle(action, version) {
        this.i.queueForAnimationIdle(action, version);
    }
    getAnimationIdleVersionNumber() {
        let iv = this.i.getAnimationIdleVersionNumber();
        return (iv);
    }
    isAnimationActive() {
        let iv = this.i.isAnimationActive();
        return (iv);
    }
    /**
     * Manually starts a tiled zoom if one isn't already running.
    
    */
    startTiledZoomingIfNecessary() {
        this.i.ri();
    }
    /**
     * Manually ends a tiled zoom if one is running.
    
    */
    endTiledZoomingIfRunning() {
        this.i.nl();
    }
    /**
     * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
    
    */
    clearTileZoomCache() {
        this.i.nf();
    }
    /**
     * Performs zoom in action on the chart by specified percentage of current window rect
    
    */
    zoomIn(percentage) {
        this.i.rz(percentage);
    }
    /**
     * Performs zoom out action on the chart by specified percentage of current window rect
    
    */
    zoomOut(percentage) {
        this.i.r0(percentage);
    }
    /**
     * Resets the zoom level to default.
    
    */
    resetZoom() {
        this.i.q8();
    }
    cancelManipulation() {
        this.i.na();
    }
    /**
     * Gets actual window scale for horizontal dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleHorizontal: number = chart.getActualWindowScaleHorizontal();
    * ```
    */
    getActualWindowScaleHorizontal() {
        let iv = this.i.hs();
        return (iv);
    }
    /**
     * Gets actual window scale for vertical dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleVertical: number = chart.getActualWindowScaleVertical();
    * ```
    */
    getActualWindowScaleVertical() {
        let iv = this.i.ht();
        return (iv);
    }
    /**
     * Notification from the containing object that the container has been resized.
    
    */
    notifyContainerResized() {
        this.i.notifyContainerResized();
    }
    /**
     * Attaches the given series to the chart.
    
    * @param s  * The series to attach to the chart.
    */
    attachSeries(s) {
        this.i.m8((s == null ? null : s.i));
    }
    notifySetItem(source_, index, oldItem, newItem) {
        this.i.og(source_, index, oldItem, newItem);
    }
    /**
     * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
    
    * @param source_  * The data source which was cleared or reset.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    notifyClearItems(source_) {
        this.i.n7(source_);
    }
    notifyInsertItem(source_, index, newItem) {
        this.i.oe(source_, index, newItem);
    }
    notifyRemoveItem(source_, index, oldItem) {
        this.i.of(source_, index, oldItem);
    }
    /**
     * Release any resources held by the control.
    
    */
    destroy() {
        this.i.destroy();
    }
    getCurrentActualWindowRect() {
        let iv = this.i.wa();
        return fromRect(iv);
    }
    renderToImage(width, height) {
        let iv = this.i.jb(width, height);
        return (iv);
    }
    /**
     * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the SeriesViewer.
    
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    flush() {
        this.i.flush();
    }
    captureImage(settings) {
        this.i.nb((settings == null ? null : settings.i));
    }
    /**
     * Occurs when the left mouse button is pressed while the mouse pointer is over the plot area.
    */
    get plotAreaMouseLeftButtonDown() {
        return this._plotAreaMouseLeftButtonDown;
    }
    set plotAreaMouseLeftButtonDown(ev) {
        if (this._plotAreaMouseLeftButtonDown_wrapped !== null) {
            this.i.plotAreaMouseLeftButtonDown = delegateRemove(this.i.plotAreaMouseLeftButtonDown, this._plotAreaMouseLeftButtonDown_wrapped);
            this._plotAreaMouseLeftButtonDown_wrapped = null;
            this._plotAreaMouseLeftButtonDown = null;
        }
        this._plotAreaMouseLeftButtonDown = ev;
        this._plotAreaMouseLeftButtonDown_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaMouseLeftButtonDown) {
                this.beforePlotAreaMouseLeftButtonDown(this, outerArgs);
            }
            if (this._plotAreaMouseLeftButtonDown) {
                this._plotAreaMouseLeftButtonDown(this, outerArgs);
            }
        };
        this.i.plotAreaMouseLeftButtonDown = delegateCombine(this.i.plotAreaMouseLeftButtonDown, this._plotAreaMouseLeftButtonDown_wrapped);
        ;
    }
    /**
     * Occurs when the left mouse button is pressed while the mouse pointer is over the plot area.
    */
    get plotAreaMouseLeftButtonUp() {
        return this._plotAreaMouseLeftButtonUp;
    }
    set plotAreaMouseLeftButtonUp(ev) {
        if (this._plotAreaMouseLeftButtonUp_wrapped !== null) {
            this.i.plotAreaMouseLeftButtonUp = delegateRemove(this.i.plotAreaMouseLeftButtonUp, this._plotAreaMouseLeftButtonUp_wrapped);
            this._plotAreaMouseLeftButtonUp_wrapped = null;
            this._plotAreaMouseLeftButtonUp = null;
        }
        this._plotAreaMouseLeftButtonUp = ev;
        this._plotAreaMouseLeftButtonUp_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaMouseLeftButtonUp) {
                this.beforePlotAreaMouseLeftButtonUp(this, outerArgs);
            }
            if (this._plotAreaMouseLeftButtonUp) {
                this._plotAreaMouseLeftButtonUp(this, outerArgs);
            }
        };
        this.i.plotAreaMouseLeftButtonUp = delegateCombine(this.i.plotAreaMouseLeftButtonUp, this._plotAreaMouseLeftButtonUp_wrapped);
        ;
    }
    /**
     * Occurs when the left mouse button is clicked while the mouse pointer is over the plot area.
    */
    get plotAreaClicked() {
        return this._plotAreaClicked;
    }
    set plotAreaClicked(ev) {
        if (this._plotAreaClicked_wrapped !== null) {
            this.i.plotAreaClicked = delegateRemove(this.i.plotAreaClicked, this._plotAreaClicked_wrapped);
            this._plotAreaClicked_wrapped = null;
            this._plotAreaClicked = null;
        }
        this._plotAreaClicked = ev;
        this._plotAreaClicked_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaClicked) {
                this.beforePlotAreaClicked(this, outerArgs);
            }
            if (this._plotAreaClicked) {
                this._plotAreaClicked(this, outerArgs);
            }
        };
        this.i.plotAreaClicked = delegateCombine(this.i.plotAreaClicked, this._plotAreaClicked_wrapped);
        ;
    }
    /**
     * Occurs when the pointer enters the plot area.
    */
    get plotAreaMouseEnter() {
        return this._plotAreaMouseEnter;
    }
    set plotAreaMouseEnter(ev) {
        if (this._plotAreaMouseEnter_wrapped !== null) {
            this.i.plotAreaMouseEnter = delegateRemove(this.i.plotAreaMouseEnter, this._plotAreaMouseEnter_wrapped);
            this._plotAreaMouseEnter_wrapped = null;
            this._plotAreaMouseEnter = null;
        }
        this._plotAreaMouseEnter = ev;
        this._plotAreaMouseEnter_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaMouseEnter) {
                this.beforePlotAreaMouseEnter(this, outerArgs);
            }
            if (this._plotAreaMouseEnter) {
                this._plotAreaMouseEnter(this, outerArgs);
            }
        };
        this.i.plotAreaMouseEnter = delegateCombine(this.i.plotAreaMouseEnter, this._plotAreaMouseEnter_wrapped);
        ;
    }
    /**
     * Occurs when the pointer exits the plot area.
    */
    get plotAreaMouseLeave() {
        return this._plotAreaMouseLeave;
    }
    set plotAreaMouseLeave(ev) {
        if (this._plotAreaMouseLeave_wrapped !== null) {
            this.i.plotAreaMouseLeave = delegateRemove(this.i.plotAreaMouseLeave, this._plotAreaMouseLeave_wrapped);
            this._plotAreaMouseLeave_wrapped = null;
            this._plotAreaMouseLeave = null;
        }
        this._plotAreaMouseLeave = ev;
        this._plotAreaMouseLeave_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaMouseLeave) {
                this.beforePlotAreaMouseLeave(this, outerArgs);
            }
            if (this._plotAreaMouseLeave) {
                this._plotAreaMouseLeave(this, outerArgs);
            }
        };
        this.i.plotAreaMouseLeave = delegateCombine(this.i.plotAreaMouseLeave, this._plotAreaMouseLeave_wrapped);
        ;
    }
    /**
     * Occurs when the pointer if over the plot area.
    */
    get plotAreaMouseOver() {
        return this._plotAreaMouseOver;
    }
    set plotAreaMouseOver(ev) {
        if (this._plotAreaMouseOver_wrapped !== null) {
            this.i.plotAreaMouseOver = delegateRemove(this.i.plotAreaMouseOver, this._plotAreaMouseOver_wrapped);
            this._plotAreaMouseOver_wrapped = null;
            this._plotAreaMouseOver = null;
        }
        this._plotAreaMouseOver = ev;
        this._plotAreaMouseOver_wrapped = (o, e) => {
            let outerArgs = new IgrPlotAreaMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlotAreaMouseOver) {
                this.beforePlotAreaMouseOver(this, outerArgs);
            }
            if (this._plotAreaMouseOver) {
                this._plotAreaMouseOver(this, outerArgs);
            }
        };
        this.i.plotAreaMouseOver = delegateCombine(this.i.plotAreaMouseOver, this._plotAreaMouseOver_wrapped);
        ;
    }
    /**
     * Occurs when the cursors are moved over a series in this SeriesViewer.
    */
    get seriesCursorMouseMove() {
        return this._seriesCursorMouseMove;
    }
    set seriesCursorMouseMove(ev) {
        if (this._seriesCursorMouseMove_wrapped !== null) {
            this.i.seriesCursorMouseMove = delegateRemove(this.i.seriesCursorMouseMove, this._seriesCursorMouseMove_wrapped);
            this._seriesCursorMouseMove_wrapped = null;
            this._seriesCursorMouseMove = null;
        }
        this._seriesCursorMouseMove = ev;
        this._seriesCursorMouseMove_wrapped = (o, e) => {
            let outerArgs = new IgrChartCursorEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesCursorMouseMove) {
                this.beforeSeriesCursorMouseMove(this, outerArgs);
            }
            if (this._seriesCursorMouseMove) {
                this._seriesCursorMouseMove(this, outerArgs);
            }
        };
        this.i.seriesCursorMouseMove = delegateCombine(this.i.seriesCursorMouseMove, this._seriesCursorMouseMove_wrapped);
        ;
    }
    /**
     * Occurs when the left mouse button is pressed while the mouse pointer is over a Series.
    *
    * The `SeriesMouseLeftButtonDown` event occurs when the left mouse button is pressed while the mouse pointer is over an element of this chart.
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * public onSeriesMouseLeftButtonDown(event: {sender: any, args: DataChartMouseButtonEventArgs})
    * {
    *     var item = event.args.item;
    * }
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	seriesMouseLeftButtonDown= {this.onSeriesMouseLeftButtonDown}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get seriesMouseLeftButtonDown() {
        return this._seriesMouseLeftButtonDown;
    }
    set seriesMouseLeftButtonDown(ev) {
        if (this._seriesMouseLeftButtonDown_wrapped !== null) {
            this.i.seriesMouseLeftButtonDown = delegateRemove(this.i.seriesMouseLeftButtonDown, this._seriesMouseLeftButtonDown_wrapped);
            this._seriesMouseLeftButtonDown_wrapped = null;
            this._seriesMouseLeftButtonDown = null;
        }
        this._seriesMouseLeftButtonDown = ev;
        this._seriesMouseLeftButtonDown_wrapped = (o, e) => {
            let outerArgs = new IgrDataChartMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesMouseLeftButtonDown) {
                this.beforeSeriesMouseLeftButtonDown(this, outerArgs);
            }
            if (this._seriesMouseLeftButtonDown) {
                this._seriesMouseLeftButtonDown(this, outerArgs);
            }
        };
        this.i.seriesMouseLeftButtonDown = delegateCombine(this.i.seriesMouseLeftButtonDown, this._seriesMouseLeftButtonDown_wrapped);
        ;
    }
    /**
     * Occurs when the left mouse button is released while the mouse pointer is over a Series.
    *
    * The `SeriesMouseLeftButtonUp` event occurs when the left mouse button is released while the mouse pointer is over an element of this chart.
    *
    * &lt;-- position: content member-->
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * public onSeriesMouseLeftButtonUp(event: {sender: any, args: DataChartMouseButtonEventArgs})
    * {
    *     var item = event.args.item;
    * }
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	seriesMouseLeftButtonUp ={this.onSeriesMouseLeftButtonUp}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * public onSeriesMouseLeftButtonUp =(event: any, args: DataChartMouseButtonEventArgs )
    * {
    *
    * }
    * ```
    */
    get seriesMouseLeftButtonUp() {
        return this._seriesMouseLeftButtonUp;
    }
    set seriesMouseLeftButtonUp(ev) {
        if (this._seriesMouseLeftButtonUp_wrapped !== null) {
            this.i.seriesMouseLeftButtonUp = delegateRemove(this.i.seriesMouseLeftButtonUp, this._seriesMouseLeftButtonUp_wrapped);
            this._seriesMouseLeftButtonUp_wrapped = null;
            this._seriesMouseLeftButtonUp = null;
        }
        this._seriesMouseLeftButtonUp = ev;
        this._seriesMouseLeftButtonUp_wrapped = (o, e) => {
            let outerArgs = new IgrDataChartMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesMouseLeftButtonUp) {
                this.beforeSeriesMouseLeftButtonUp(this, outerArgs);
            }
            if (this._seriesMouseLeftButtonUp) {
                this._seriesMouseLeftButtonUp(this, outerArgs);
            }
        };
        this.i.seriesMouseLeftButtonUp = delegateCombine(this.i.seriesMouseLeftButtonUp, this._seriesMouseLeftButtonUp_wrapped);
        ;
    }
    /**
     * Occurs when the left mouse button is released while the mouse pointer is over a Series.
    */
    get seriesClick() {
        return this._seriesClick;
    }
    set seriesClick(ev) {
        if (this._seriesClick_wrapped !== null) {
            this.i.seriesClick = delegateRemove(this.i.seriesClick, this._seriesClick_wrapped);
            this._seriesClick_wrapped = null;
            this._seriesClick = null;
        }
        this._seriesClick = ev;
        this._seriesClick_wrapped = (o, e) => {
            let outerArgs = new IgrDataChartMouseButtonEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesClick) {
                this.beforeSeriesClick(this, outerArgs);
            }
            if (this._seriesClick) {
                this._seriesClick(this, outerArgs);
            }
        };
        this.i.seriesClick = delegateCombine(this.i.seriesClick, this._seriesClick_wrapped);
        ;
    }
    /**
     * Occurs when the mouse pointer moves while over a Series.
    *
    * The `SeriesMouseMove` event occurs when the left mouse pointer moves while over an element of this chart.
    *
    * &lt;-- position: content member-->
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * public onSeriesMouseMove(event: {sender: any, args: ChartMouseEventArgs})
    * {
    *     var item = event.args.item;
    * }
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	seriesMouseMove={this.onSeriesMouseMove} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * public onSeriesMouseMove =( event: any, args: ChartMouseEventArgs) => {
    *                  }
    * ```
    */
    get seriesMouseMove() {
        return this._seriesMouseMove;
    }
    set seriesMouseMove(ev) {
        if (this._seriesMouseMove_wrapped !== null) {
            this.i.seriesMouseMove = delegateRemove(this.i.seriesMouseMove, this._seriesMouseMove_wrapped);
            this._seriesMouseMove_wrapped = null;
            this._seriesMouseMove = null;
        }
        this._seriesMouseMove = ev;
        this._seriesMouseMove_wrapped = (o, e) => {
            let outerArgs = new IgrChartMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesMouseMove) {
                this.beforeSeriesMouseMove(this, outerArgs);
            }
            if (this._seriesMouseMove) {
                this._seriesMouseMove(this, outerArgs);
            }
        };
        this.i.seriesMouseMove = delegateCombine(this.i.seriesMouseMove, this._seriesMouseMove_wrapped);
        ;
    }
    /**
     * Occurs when the mouse pointer enters a Series.
    *
    * The `SeriesMouseEnter` event occurs when the left mouse pointer enters an element of this chart.
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * public onSeriesMouseEnter(event: {sender: any, args: ChartMouseEventArgs})
    * {
    *     var item = event.args.item;
    * }
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	seriesMouseEnter={this.onSeriesMouseEnter}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get seriesMouseEnter() {
        return this._seriesMouseEnter;
    }
    set seriesMouseEnter(ev) {
        if (this._seriesMouseEnter_wrapped !== null) {
            this.i.seriesMouseEnter = delegateRemove(this.i.seriesMouseEnter, this._seriesMouseEnter_wrapped);
            this._seriesMouseEnter_wrapped = null;
            this._seriesMouseEnter = null;
        }
        this._seriesMouseEnter = ev;
        this._seriesMouseEnter_wrapped = (o, e) => {
            let outerArgs = new IgrChartMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesMouseEnter) {
                this.beforeSeriesMouseEnter(this, outerArgs);
            }
            if (this._seriesMouseEnter) {
                this._seriesMouseEnter(this, outerArgs);
            }
        };
        this.i.seriesMouseEnter = delegateCombine(this.i.seriesMouseEnter, this._seriesMouseEnter_wrapped);
        ;
    }
    /**
     * Occurs when the mouse pointer leaves a Series.
    *
    * The `SeriesMouseLeave` event occurs when the left mouse pointer leaves an element of this chart.
    *
    * ```ts
    * public onSeriesMouseLeave(event: {sender: any, args: ChartMouseEventArgs})
    * {
    *     var item = event.args.item;
    * }
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	 seriesMouseLeave ={this.onSeriesMouseLeave}>
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    get seriesMouseLeave() {
        return this._seriesMouseLeave;
    }
    set seriesMouseLeave(ev) {
        if (this._seriesMouseLeave_wrapped !== null) {
            this.i.seriesMouseLeave = delegateRemove(this.i.seriesMouseLeave, this._seriesMouseLeave_wrapped);
            this._seriesMouseLeave_wrapped = null;
            this._seriesMouseLeave = null;
        }
        this._seriesMouseLeave = ev;
        this._seriesMouseLeave_wrapped = (o, e) => {
            let outerArgs = new IgrChartMouseEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSeriesMouseLeave) {
                this.beforeSeriesMouseLeave(this, outerArgs);
            }
            if (this._seriesMouseLeave) {
                this._seriesMouseLeave(this, outerArgs);
            }
        };
        this.i.seriesMouseLeave = delegateCombine(this.i.seriesMouseLeave, this._seriesMouseLeave_wrapped);
        ;
    }
    /**
     * Raised when an ongoing manipulation of the series viewer is started.
    */
    get viewerManipulationStarting() {
        return this._viewerManipulationStarting;
    }
    set viewerManipulationStarting(ev) {
        if (this._viewerManipulationStarting_wrapped !== null) {
            this.i.viewerManipulationStarting = delegateRemove(this.i.viewerManipulationStarting, this._viewerManipulationStarting_wrapped);
            this._viewerManipulationStarting_wrapped = null;
            this._viewerManipulationStarting = null;
        }
        this._viewerManipulationStarting = ev;
        this._viewerManipulationStarting_wrapped = (o, e) => {
            let outerArgs = new IgrSeriesViewerManipulationEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeViewerManipulationStarting) {
                this.beforeViewerManipulationStarting(this, outerArgs);
            }
            if (this._viewerManipulationStarting) {
                this._viewerManipulationStarting(this, outerArgs);
            }
        };
        this.i.viewerManipulationStarting = delegateCombine(this.i.viewerManipulationStarting, this._viewerManipulationStarting_wrapped);
        ;
    }
    /**
     * Raised when an ongoing manipulation of the series viewer is ended.
    */
    get viewerManipulationEnding() {
        return this._viewerManipulationEnding;
    }
    set viewerManipulationEnding(ev) {
        if (this._viewerManipulationEnding_wrapped !== null) {
            this.i.viewerManipulationEnding = delegateRemove(this.i.viewerManipulationEnding, this._viewerManipulationEnding_wrapped);
            this._viewerManipulationEnding_wrapped = null;
            this._viewerManipulationEnding = null;
        }
        this._viewerManipulationEnding = ev;
        this._viewerManipulationEnding_wrapped = (o, e) => {
            let outerArgs = new IgrSeriesViewerManipulationEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeViewerManipulationEnding) {
                this.beforeViewerManipulationEnding(this, outerArgs);
            }
            if (this._viewerManipulationEnding) {
                this._viewerManipulationEnding(this, outerArgs);
            }
        };
        this.i.viewerManipulationEnding = delegateCombine(this.i.viewerManipulationEnding, this._viewerManipulationEnding_wrapped);
        ;
    }
    /**
     * Occurs just after the current SeriesViewer's window rectangle is changed.
    *
    * &lt;-- position: content member-->
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    * <IgrDataChart
    * 	width="100%"
    * 	height="100%"
    * 	dataSource={this.data}
    * 	windowRectChanged={this.onWindowRectChanged} >
    * <IgrCategoryXAxis name="xAxis" label="Year"/>
    * <IgrNumericYAxis name="yAxis" minimumValue={0} />
    * <IgrLineSeries name="series3" title="Russia"
    *     valueMemberPath="Russia"
    *     xAxisName="xAxis"
    *     yAxisName="yAxis"
    *     markerType={this.state.markersType} />
    * </IgrDataChart>
    * ```
    *
    * ```ts
    * public onWindowRectChanged =( s:any, e: RectChangedEventArgs) => {
    *
    *        }
    * ```
    */
    get windowRectChanged() {
        return this._windowRectChanged;
    }
    set windowRectChanged(ev) {
        if (this._windowRectChanged_wrapped !== null) {
            this.i.windowRectChanged = delegateRemove(this.i.windowRectChanged, this._windowRectChanged_wrapped);
            this._windowRectChanged_wrapped = null;
            this._windowRectChanged = null;
        }
        this._windowRectChanged = ev;
        this._windowRectChanged_wrapped = (o, e) => {
            let outerArgs = new IgrRectChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeWindowRectChanged) {
                this.beforeWindowRectChanged(this, outerArgs);
            }
            if (this._windowRectChanged) {
                this._windowRectChanged(this, outerArgs);
            }
        };
        this.i.windowRectChanged = delegateCombine(this.i.windowRectChanged, this._windowRectChanged_wrapped);
        ;
    }
    /**
     * Occurs after the size of the series viewer changes.
    *
    * &lt;-- position: content member-->
    *
    * &lt;-- position: content member-->
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource}
    * 	sizeChanged={this.onSizeChanged=} >
    *
    *     <IgrNumericXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * public onSizeChanged =(event: any, args: RectChangedEventArgs}){
    *
    * }
    * ```
    */
    get sizeChanged() {
        return this._sizeChanged;
    }
    set sizeChanged(ev) {
        if (this._sizeChanged_wrapped !== null) {
            this.i.sizeChanged = delegateRemove(this.i.sizeChanged, this._sizeChanged_wrapped);
            this._sizeChanged_wrapped = null;
            this._sizeChanged = null;
        }
        this._sizeChanged = ev;
        this._sizeChanged_wrapped = (o, e) => {
            let outerArgs = new IgrRectChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSizeChanged) {
                this.beforeSizeChanged(this, outerArgs);
            }
            if (this._sizeChanged) {
                this._sizeChanged(this, outerArgs);
            }
        };
        this.i.sizeChanged = delegateCombine(this.i.sizeChanged, this._sizeChanged_wrapped);
        ;
    }
    /**
     * Raised when the actual window rectangle of the SeriesViewer changes.
    */
    get actualWindowRectChanged() {
        return this._actualWindowRectChanged;
    }
    set actualWindowRectChanged(ev) {
        if (this._actualWindowRectChanged_wrapped !== null) {
            this.i.actualWindowRectChanged = delegateRemove(this.i.actualWindowRectChanged, this._actualWindowRectChanged_wrapped);
            this._actualWindowRectChanged_wrapped = null;
            this._actualWindowRectChanged = null;
        }
        this._actualWindowRectChanged = ev;
        this._actualWindowRectChanged_wrapped = (o, e) => {
            let outerArgs = new IgrRectChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeActualWindowRectChanged) {
                this.beforeActualWindowRectChanged(this, outerArgs);
            }
            if (this._actualWindowRectChanged) {
                this._actualWindowRectChanged(this, outerArgs);
            }
        };
        this.i.actualWindowRectChanged = delegateCombine(this.i.actualWindowRectChanged, this._actualWindowRectChanged_wrapped);
        ;
    }
    /**
     * Occurs just after the current SeriesViewer's grid area rectangle is changed.
     * The grid area may change as the result of the SeriesViewer being resized, or
     * of an axis being added or changing size, possibly in another SeriesViewer.
    */
    get gridAreaRectChanged() {
        return this._gridAreaRectChanged;
    }
    set gridAreaRectChanged(ev) {
        if (this._gridAreaRectChanged_wrapped !== null) {
            this.i.gridAreaRectChanged = delegateRemove(this.i.gridAreaRectChanged, this._gridAreaRectChanged_wrapped);
            this._gridAreaRectChanged_wrapped = null;
            this._gridAreaRectChanged = null;
        }
        this._gridAreaRectChanged = ev;
        this._gridAreaRectChanged_wrapped = (o, e) => {
            let outerArgs = new IgrRectChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeGridAreaRectChanged) {
                this.beforeGridAreaRectChanged(this, outerArgs);
            }
            if (this._gridAreaRectChanged) {
                this._gridAreaRectChanged(this, outerArgs);
            }
        };
        this.i.gridAreaRectChanged = delegateCombine(this.i.gridAreaRectChanged, this._gridAreaRectChanged_wrapped);
        ;
    }
    /**
     * Raised when the SelectedItems collection has changed.
    */
    get selectedSeriesItemsChanged() {
        return this._selectedSeriesItemsChanged;
    }
    set selectedSeriesItemsChanged(ev) {
        if (this._selectedSeriesItemsChanged_wrapped !== null) {
            this.i.selectedSeriesItemsChanged = delegateRemove(this.i.selectedSeriesItemsChanged, this._selectedSeriesItemsChanged_wrapped);
            this._selectedSeriesItemsChanged_wrapped = null;
            this._selectedSeriesItemsChanged = null;
        }
        this._selectedSeriesItemsChanged = ev;
        this._selectedSeriesItemsChanged_wrapped = (o, e) => {
            let outerArgs = new IgrSeriesViewerSelectedSeriesItemsChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSelectedSeriesItemsChanged) {
                this.beforeSelectedSeriesItemsChanged(this, outerArgs);
            }
            if (this._selectedSeriesItemsChanged) {
                this._selectedSeriesItemsChanged(this, outerArgs);
            }
        };
        this.i.selectedSeriesItemsChanged = delegateCombine(this.i.selectedSeriesItemsChanged, this._selectedSeriesItemsChanged_wrapped);
        ;
    }
    /**
     * Raised when the SelectedItems collection has changed.
    */
    get focusedSeriesItemsChanged() {
        return this._focusedSeriesItemsChanged;
    }
    set focusedSeriesItemsChanged(ev) {
        if (this._focusedSeriesItemsChanged_wrapped !== null) {
            this.i.focusedSeriesItemsChanged = delegateRemove(this.i.focusedSeriesItemsChanged, this._focusedSeriesItemsChanged_wrapped);
            this._focusedSeriesItemsChanged_wrapped = null;
            this._focusedSeriesItemsChanged = null;
        }
        this._focusedSeriesItemsChanged = ev;
        this._focusedSeriesItemsChanged_wrapped = (o, e) => {
            let outerArgs = new IgrSeriesViewerSelectedSeriesItemsChangedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeFocusedSeriesItemsChanged) {
                this.beforeFocusedSeriesItemsChanged(this, outerArgs);
            }
            if (this._focusedSeriesItemsChanged) {
                this._focusedSeriesItemsChanged(this, outerArgs);
            }
        };
        this.i.focusedSeriesItemsChanged = delegateCombine(this.i.focusedSeriesItemsChanged, this._focusedSeriesItemsChanged_wrapped);
        ;
    }
    /**
     * Raised when the SeriesViewer's processing for an update has completed.
    */
    get refreshCompleted() {
        return this._refreshCompleted;
    }
    set refreshCompleted(ev) {
        if (this._refreshCompleted_wrapped !== null) {
            this.i.refreshCompleted = delegateRemove(this.i.refreshCompleted, this._refreshCompleted_wrapped);
            this._refreshCompleted_wrapped = null;
            this._refreshCompleted = null;
        }
        this._refreshCompleted = ev;
        this._refreshCompleted_wrapped = (o, e) => {
            let outerArgs = new IgrRefreshCompletedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeRefreshCompleted) {
                this.beforeRefreshCompleted(this, outerArgs);
            }
            if (this._refreshCompleted) {
                this._refreshCompleted(this, outerArgs);
            }
        };
        this.i.refreshCompleted = delegateCombine(this.i.refreshCompleted, this._refreshCompleted_wrapped);
        ;
    }
    /**
     * Event raised when an image of the component is saved
    */
    get imageCaptured() {
        return this._imageCaptured;
    }
    set imageCaptured(ev) {
        if (this._imageCaptured_wrapped !== null) {
            this.i.imageCaptured = delegateRemove(this.i.imageCaptured, this._imageCaptured_wrapped);
            this._imageCaptured_wrapped = null;
            this._imageCaptured = null;
        }
        this._imageCaptured = ev;
        this._imageCaptured_wrapped = (o, e) => {
            let outerArgs = new IgrImageCapturedEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeImageCaptured) {
                this.beforeImageCaptured(this, outerArgs);
            }
            if (this._imageCaptured) {
                this._imageCaptured(this, outerArgs);
            }
        };
        this.i.imageCaptured = delegateCombine(this.i.imageCaptured, this._imageCaptured_wrapped);
        ;
    }
}
