import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { RelativeStrengthIndexIndicator } from "./RelativeStrengthIndexIndicator";
/**
 * Represents a IgxDataChartComponent Relative Strength Index indicator series.
 * Default required members: Close
*
* The `RelativeStrengthIndexIndicator` class represents Relative Strength Index indicator series for the IgxDataChartComponent .
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRelativeStrengthIndexIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		volumeMemberPath="Volume"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrRelativeStrengthIndexIndicator({name :"series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* ```
*/
var IgrRelativeStrengthIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRelativeStrengthIndexIndicator, _super);
    function IgrRelativeStrengthIndexIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrRelativeStrengthIndexIndicator.prototype.createImplementation = function () {
        return new RelativeStrengthIndexIndicator();
    };
    Object.defineProperty(IgrRelativeStrengthIndexIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRelativeStrengthIndexIndicator.prototype, "defaultDisplayType", {
        /**
         * Gets default display type for the current Financial Indicator
        */
        get: function () {
            return this.i.aa2;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRelativeStrengthIndexIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current RelativeStrengthIndexIndicator object.
         * The typical, and initial, value for RSI periods is 14.
        *
        * You can use the `period` property for the current RelativeStrengthIndexIndicator object.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRelativeStrengthIndexIndicator
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        * 		openMemberPath="Open"
        * 		volumeMemberPath="Volume"
        *         highMemberPath="High"
        *         lowMemberPath="Low"
        * 		period=30 />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * this.series.period = 30;
        * ```
        */
        get: function () {
            return this.i.acg;
        },
        set: function (v) {
            this.i.acg = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRelativeStrengthIndexIndicator;
}(IgrStrategyBasedIndicator));
export { IgrRelativeStrengthIndexIndicator };
