import { IgRect } from "igniteui-react-core";
import { IgPoint } from "igniteui-react-core";
import { LegendEmptyValuesMode } from "igniteui-react-core";
import { IgrAnchoredRadialSeries, IIgrAnchoredRadialSeriesProps } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
export declare class IgrRadialPieSeries extends IgrAnchoredRadialSeries<IIgrRadialPieSeriesProps> {
    protected createImplementation(): RadialPieSeries;
    /**
                                 * @hidden
                                 */
    get i(): RadialPieSeries;
    constructor(props: IIgrRadialPieSeriesProps);
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie(): boolean;
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred(): boolean;
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX(): number;
    set radiusX(v: number);
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY(): number;
    set radiusY(v: number);
    /**
     * Gets or sets the property name that contains the legend labels.
    */
    get legendLabelMemberPath(): string;
    set legendLabelMemberPath(v: string);
    /**
     * Determines display mode for zero values in the legend.
    */
    get legendEmptyValuesMode(): LegendEmptyValuesMode;
    set legendEmptyValuesMode(v: LegendEmptyValuesMode);
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
}
export interface IIgrRadialPieSeriesProps extends IIgrAnchoredRadialSeriesProps {
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    radiusX?: number | string;
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    radiusY?: number | string;
    /**
     * Gets or sets the property name that contains the legend labels.
    */
    legendLabelMemberPath?: string;
    /**
     * Determines display mode for zero values in the legend.
    */
    legendEmptyValuesMode?: LegendEmptyValuesMode | string;
}
