import { IgrHorizontalRangeCategorySeries, IIgrHorizontalRangeCategorySeriesProps } from "./igr-horizontal-range-category-series";
import { RangeAreaSeries } from "./RangeAreaSeries";
/**
 * Represents a IgxDataChartComponent range area series.
*
* The `RangeAreaSeries` class represents the range area series of the IgxDataChartComponent.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRangeAreaSeries
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrRangeAreaSeries({name:"series1"});
* series.xAxisName = this.xAxis;
* series.yAxisName = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* ```
*/
export declare class IgrRangeAreaSeries extends IgrHorizontalRangeCategorySeries<IIgrRangeAreaSeriesProps> {
    protected createImplementation(): RangeAreaSeries;
    /**
                                 * @hidden
                                 */
    get i(): RangeAreaSeries;
    constructor(props: IIgrRangeAreaSeriesProps);
    /**
     * Gets whether the current series shows an area or line shape.
    *
    * Use the `IsAreaOrLine` property to check if the current series shows an area or line shape.
    *
    * ```ts
    * var x= series.isAreaOrLine;
    * ```
    */
    get isAreaOrLine(): boolean;
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea(): boolean;
}
export interface IIgrRangeAreaSeriesProps extends IIgrHorizontalRangeCategorySeriesProps {
}
